aboutsummaryrefslogtreecommitdiffstats
path: root/src/TagFile.cxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/TagFile.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/TagFile.cxx b/src/TagFile.cxx
index 5e3711532..0e13b0530 100644
--- a/src/TagFile.cxx
+++ b/src/TagFile.cxx
@@ -46,7 +46,7 @@ tag_file_scan(const char *path_fs,
if (plugin == nullptr)
return false;
- struct input_stream *is = nullptr;
+ InputStream *is = nullptr;
Mutex mutex;
Cond cond;
@@ -58,11 +58,11 @@ tag_file_scan(const char *path_fs,
/* fall back to stream tag */
if (plugin->scan_stream != nullptr) {
/* open the input_stream (if not already
open) */
if (is == nullptr)
- is = input_stream::Open(path_fs, mutex, cond,
- IgnoreError());
+ is = InputStream::Open(path_fs, mutex, cond,
+ IgnoreError());
/* now try the stream_tag() method */
if (is != nullptr) {
@@ -58,11 +58,11 @@ tag_file_scan(const char *path_fs,
/* fall back to stream tag */
if (plugin->scan_stream != nullptr) {
- /* open the input_stream (if not already
+ /* open the InputStream (if not already
open) */
if (is == nullptr)